@@ -16,15 +16,15 @@ uint32_t SimHash(const uint32_t *data, size_t size)
 	for (size_t i = 0; i < size; i++) {
 		uint32_t local_hash = data[i];
 		for (size_t j = 0; j < 32; j++) {
-			v[j] += (local_hash & (1 << j)) ? 1 : -1;
+			v[j] += (local_hash >> j) & 1;
 		}
 	}
 
+	const int threshold = size / 2;
 	uint32_t hash = 0;
 	for (size_t i = 0; i < 32; i++) {
-		if (v[i] > 0) {
-			hash |= (1 << i);
-		}
+		const int b = v[i] > threshold ? 1 : 0;
+		hash |= (b << i);
 	}
 
 	return hash;
